#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.12
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { queue } from '@gitmars/core/lib/queue';
import getIsGitProject from '@gitmars/core/lib/git/getIsGitProject';
import getCurrentBranch from '@gitmars/core/lib/git/getCurrentBranch';
import getStashList from '@gitmars/core/lib/git/getStashList';
import { createArgs } from '@gitmars/core/lib/utils/command';
import getConfig from '#lib/conf/get';
import i18n from '#lib/locales/index';

const { red, yellow } = chalk;
const { args, options } = getConfig;
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm get").usage("[message] [index] [-k --keep [keep]]").description(i18n.__("Restore staging area file"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((message, index, opt) => {
  if (!message)
    message = getCurrentBranch();
  const list = getStashList(message);
  if (list.length === 0) {
    sh.echo(yellow(i18n.__("There are no files staged in this branch!")));
    process.exit(0);
  }
  if (index === void 0 && list.length > 1) {
    sh.echo(
      yellow(
        i18n.__(
          "There are {{length}} staging records under this branch, and the most recent one is restored by default",
          { length: String(list.length) }
        )
      )
    );
  }
  if (list.length > 2) {
    sh.echo(
      yellow(
        i18n.__(
          "There are {{length}} staging records under this branch, please clean up unnecessary staging records regularly",
          { length: String(list.length) }
        )
      )
    );
  }
  queue([
    {
      cmd: `git stash ${opt.keep ? "apply" : "pop"} ${list[index || 0].key}`,
      config: {
        again: opt.keep ? false : `git stash drop ${list[index || 0].key}`,
        success: i18n.__("File recovery successful"),
        fail: i18n.__("Recovery failed, please check for conflicts")
      }
    },
    "git reset -q HEAD -- ."
  ]);
});
program.parse(process.argv);
