#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.12
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { queue } from '@gitmars/core/lib/queue';
import getIsGitProject from '@gitmars/core/lib/git/getIsGitProject';
import getCurrentBranch from '@gitmars/core/lib/git/getCurrentBranch';
import i18n from '#lib/locales/index';

const { red } = chalk;
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm merge").usage("<name>").arguments("<name>").description(i18n.__("Merge branch code")).action((name) => {
  const current = getCurrentBranch();
  const cmd = [
    {
      cmd: `git merge --no-ff ${name}`,
      config: {
        again: false,
        success: i18n.__(
          "Merge {{source}} to {{target}} successfully",
          { source: name, target: current }
        ),
        fail: i18n.__(
          "An error occurred merging {{source} to {{target}}, please follow the instructions",
          { source: name, target: current }
        )
      }
    },
    {
      cmd: "git push",
      config: {
        again: true,
        success: i18n.__("Successful Pushed"),
        fail: i18n.__("Push failed, please follow the prompts")
      }
    }
  ];
  queue(cmd);
});
program.parse(process.argv);
